==> haskell-hslua-module-text-0.1.2.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-text
version: 0.1.2.1
id: hslua-module-text-0.1.2.1-GJySSEKM9gdGwXELrHkzEG
key: hslua-module-text-0.1.2.1-GJySSEKM9gdGwXELrHkzEG
license: MIT
copyright: © 2017 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
homepage: https://github.com/hslua/hslua-module-test
synopsis: Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.
category: Foreign
author: Albert Krewinkel
exposed: True
indefinite: False
exposed-modules:
    Foreign.Lua.Module.Text
abi: a1ac51a2633060e70d6c0ef50498a338
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hslua-module-text-0.1.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/hslua-module-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hslua-module-text-0.1.2.1
hs-libraries: HShslua-module-text-0.1.2.1-GJySSEKM9gdGwXELrHkzEG
depends:
    base-4.10.1.0 hslua-0.9.5-EteOnTFCg3G3ew5vcJlSIj
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             hslua-0.9.5-EteOnTFCg3G3ew5vcJlSIj=a565386233ab113d4e28d0284a6d60bd
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
haddock-interfaces: /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-text-0.1.2.1-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hslua-module-text.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hslua-module-text
version: 0.1.2.1
id: hslua-module-text-0.1.2.1-Jt4aCXQP0xZ6WYCdB7X5jU
key: hslua-module-text-0.1.2.1-Jt4aCXQP0xZ6WYCdB7X5jU
license: MIT
copyright: © 2017 Albert Krewinkel
maintainer: albert+hslua@zeitkraut.de
homepage: https://github.com/hslua/hslua-module-test
synopsis: Lua module for text
description:
    UTF-8 aware subset of Lua'\''s `string` module.
category: Foreign
author: Albert Krewinkel
exposed: True
indefinite: False
exposed-modules:
    Foreign.Lua.Module.Text
abi: bed5077d507a7d778858be750a58cfb1
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hslua-module-text-0.1.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/hslua-module-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/hslua-module-text-0.1.2.1
hs-libraries: HShslua-module-text-0.1.2.1-Jt4aCXQP0xZ6WYCdB7X5jU
depends:
    base-4.10.1.0 hslua-0.9.5-EBpDCOX3BRFLlz08UKDbUv
    text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             hslua-0.9.5-EBpDCOX3BRFLlz08UKDbUv=b70c4fe398dbec25cca109b49466111c
             text-1.2.3.0-912fnkqHcZz4dFvcXKwtDz=29872508833c96394f0471371217bab0
haddock-interfaces: /usr/share/doc/haskell-hslua-module-text/html/hslua-module-text.haddock
haddock-html: /usr/share/doc/haskell-hslua-module-text/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
